### Neuroseries

This package includes tools to process neural data series,
providing function for handling of timestamped data, and for irregular 
intervals. It is based on Pandas for most functionality, enhanced in the 
areas where Pandas does not satisfy the needs of the neural data analyst.

It also includes an experimental data manager attempting at keeping track 
of all code used to generate each intermediate result, making use of 
git and git-annex.

This package requires Python 3 and has been tested with Python 3.5.3.
Look at the test suite for use examples.